<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>FeatherNotes::AboutDialog</name>
    <message>
        <location filename="../../about.ui" line="177"/>
        <source>License</source>
        <translation>Licença</translation>
    </message>
</context>
<context>
    <name>FeatherNotes::ColorLabel</name>
    <message>
        <location filename="../../colorLabel.cpp" line="31"/>
        <source>Click to change color.</source>
        <translation>Clique para alterar a cor.</translation>
    </message>
    <message>
        <location filename="../../colorLabel.cpp" line="53"/>
        <source>Select Color</source>
        <translation>Selecione a cor</translation>
    </message>
</context>
<context>
    <name>FeatherNotes::FN</name>
    <message>
        <location filename="../../fn.ui" line="14"/>
        <source>FeatherNotes</source>
        <translation>FeatherNotes</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="65"/>
        <source>Next (F3)</source>
        <translation>Próximo (F3)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="68"/>
        <source>F3</source>
        <translation>F3</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="81"/>
        <source>Previous (F4)</source>
        <translation>Anterior (F4)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="84"/>
        <source>F4</source>
        <translation>F4</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="100"/>
        <source>Search...</source>
        <translation>Pesquisar...</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="115"/>
        <source>Search only in names (Ctrl+Shift+F7)</source>
        <translation>Pesquisar somente em nomes (Ctrl+Shift+F7)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="118"/>
        <source>Ctrl+Shift+F7</source>
        <translation>Ctrl+Shift+F7</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="128"/>
        <source>Search only in tags (Shift+F7)</source>
        <translation>Pesquisar somente em tags (Shift+F7)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="131"/>
        <source>Shift+F7</source>
        <translation>Shift+F7</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="144"/>
        <source>Search in all nodes (F7)</source>
        <translation>Pesquisar em todos os nós (F7)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="147"/>
        <source>F7</source>
        <translation>F7</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="186"/>
        <source>Whole Word (F6)</source>
        <translation>Palavra Inteira (F6)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="189"/>
        <source>Whole Word</source>
        <translation>Palavra Inteira</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="192"/>
        <source>F6</source>
        <translation>F6</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="167"/>
        <source>Match Case (F5)</source>
        <translation>Caso de Compatibilidade (F5)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="170"/>
        <source>Match Case</source>
        <translation>Caso de Compatibilidade</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="173"/>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="219"/>
        <source>&amp;File</source>
        <translation>&amp;Arquivo</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="223"/>
        <source>Recenl&amp;y Opened</source>
        <translation>Aberto recentemente</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="245"/>
        <source>&amp;Edit</source>
        <translation>&amp;Editar</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="264"/>
        <source>For&amp;mat</source>
        <translation>For&amp;matar</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="296"/>
        <source>&amp;Tree</source>
        <translation>&amp;Árvore</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="320"/>
        <source>&amp;Options</source>
        <translation>&amp;Opções</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="334"/>
        <source>&amp;Search</source>
        <translation>&amp;Pesquisa</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="341"/>
        <location filename="../../fn.ui" line="987"/>
        <source>&amp;Help</source>
        <translation>&amp;Ajuda</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="436"/>
        <source>Find:</source>
        <translation>Encontrar:</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="443"/>
        <source>Replace with:</source>
        <translation>Substituir com:</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="456"/>
        <source>To be replaced</source>
        <translation>Para ser substituído</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="469"/>
        <source>Replacing text</source>
        <translation>Substituir texto</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="479"/>
        <source>Previous (F9)</source>
        <translation>Anterior (F9)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="482"/>
        <source>F9</source>
        <translation>F9</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="495"/>
        <source>Next (F8)</source>
        <translation>Próximo (F8)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="498"/>
        <source>F8</source>
        <translation>F8</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="511"/>
        <source>Replace all (F10)</source>
        <translation>Substituir todos (F10)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="514"/>
        <source>F10</source>
        <translation>F10</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="531"/>
        <source>&amp;Save</source>
        <translation>&amp;Salvar</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="534"/>
        <location filename="../../fn.cpp" line="1032"/>
        <source>Save</source>
        <translation>Salvar</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="537"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="542"/>
        <location filename="../../fn.cpp" line="692"/>
        <source>&amp;Open</source>
        <translation>&amp;Abrir</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="545"/>
        <source>Open a file</source>
        <translation>Abrir um arquivo</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="548"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="556"/>
        <source>&amp;Undo</source>
        <translation>&amp;Desfazer</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="559"/>
        <source>Undo</source>
        <translation>Desfazer</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="562"/>
        <source>Ctrl+Z</source>
        <translation>Ctrl+Z</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="570"/>
        <source>&amp;Redo</source>
        <translation>&amp;Refazer</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="573"/>
        <source>Redo</source>
        <translation>Refazer</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="576"/>
        <source>Ctrl+Shift+Z</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="584"/>
        <source>&amp;Find</source>
        <translation>&amp;Encontrar</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="587"/>
        <source>Show/hide searchbar</source>
        <translation>Exibir/ocultar barra de pesquisa</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="590"/>
        <source>Ctrl+F</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="598"/>
        <source>&amp;Clear All Formats</source>
        <translation>&amp;Limpar Todos Formatos</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="601"/>
        <source>Clear all formats</source>
        <translation>Limpar todos formatos</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="604"/>
        <source>Ctrl+E</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="615"/>
        <source>&amp;Bold</source>
        <translation>&amp;Negrito</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="618"/>
        <source>Bold</source>
        <translation>Negrito</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="621"/>
        <source>Ctrl+B</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="632"/>
        <source>&amp;Italic</source>
        <translation>&amp;Itálico</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="635"/>
        <source>Italic</source>
        <translation>Itálico</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="638"/>
        <source>Ctrl+I</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="649"/>
        <source>&amp;Underline</source>
        <translation>&amp;Sublinhado</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="652"/>
        <source>Underline</source>
        <translation>Sublinhado</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="655"/>
        <source>Ctrl+U</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="666"/>
        <source>&amp;Strike Through</source>
        <translation>&amp;Tachado</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="669"/>
        <source>Strike through</source>
        <translation>Tachado</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="672"/>
        <source>Ctrl+T</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="680"/>
        <source>Te&amp;xt Color</source>
        <translation>Cor do Te&amp;xto</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="683"/>
        <source>Text color</source>
        <translation>Cor do texto</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="686"/>
        <source>Alt+Shift+T</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="694"/>
        <source>Back&amp;ground Color</source>
        <translation>Cor de Plano de &amp;Fundo</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="697"/>
        <source>Background color</source>
        <translation>Cor de plano de fundo</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="700"/>
        <source>Alt+Shift+B</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="705"/>
        <source>Options</source>
        <translation>Opções</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="710"/>
        <location filename="../../fn.cpp" line="691"/>
        <source>&amp;New Note</source>
        <translation>&amp;Nova Nota</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="713"/>
        <source>Ctrl+Alt+Shift+N</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="721"/>
        <source>Save &amp;As</source>
        <translation>Salvar &amp;Como</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="724"/>
        <source>Ctrl+Shift+S</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="732"/>
        <source>&amp;Print</source>
        <translation>&amp;Imprimir</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="735"/>
        <source>Ctrl+P</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="743"/>
        <source>P&amp;rint with Sub-Nodes</source>
        <translation>Imp&amp;rimir com Sub-Nós</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="751"/>
        <source>Set Pass&amp;word</source>
        <translation>Configurar &amp;Senha</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="756"/>
        <location filename="../../fn.cpp" line="694"/>
        <source>&amp;Quit</source>
        <translation>&amp;Sair</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="759"/>
        <source>Ctrl+Q</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="767"/>
        <source>&amp;Cut</source>
        <translation>&amp;Recortar</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="770"/>
        <source>Ctrl+X</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="778"/>
        <source>C&amp;opy</source>
        <translation>C&amp;opiar</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="781"/>
        <source>Ctrl+C</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="789"/>
        <source>&amp;Paste</source>
        <translation>&amp;Colar</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="792"/>
        <source>Ctrl+V</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="800"/>
        <source>&amp;Delete</source>
        <translation>&amp;Excluir</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="808"/>
        <source>&amp;Select All</source>
        <translation>&amp;Selecionar Todos</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="811"/>
        <source>Ctrl+A</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="819"/>
        <source>E&amp;mbed Image</source>
        <translation>In&amp;corporar Imagem</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="822"/>
        <location filename="../../fn.cpp" line="4449"/>
        <source>Embed Image</source>
        <translation>Inserir Imagem</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="825"/>
        <source>Ctrl+Alt+Shift+I</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="833"/>
        <source>E&amp;xpand All</source>
        <translation>E&amp;xpandir Todos</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="836"/>
        <source>Ctrl+Shift+Down</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="844"/>
        <source>Collap&amp;se All</source>
        <translation>Reco&amp;lher Todos</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="847"/>
        <source>Ctrl+Shift+Up</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="855"/>
        <source>&amp;Append Sibling</source>
        <translation>&amp;Acrescentar Irmão</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="858"/>
        <source>Ctrl+N</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="866"/>
        <source>Append &amp;Child</source>
        <translation>Acrescentar &amp;Filho</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="869"/>
        <source>Ctrl+Shift+N</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="877"/>
        <source>&amp;Delete Node</source>
        <translation>&amp;Excluir Nó</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="880"/>
        <source>Ctrl+D</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="888"/>
        <source>Move &amp;Up</source>
        <translation>Mover &amp;Acima</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="891"/>
        <source>Alt+Up</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="899"/>
        <source>Move Do&amp;wn</source>
        <translation>Mover Abai&amp;xo</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="902"/>
        <source>Alt+Down</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="910"/>
        <source>Re&amp;name Node</source>
        <translation>Re&amp;nomear Nó</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="913"/>
        <source>Ctrl+Shift+R</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="918"/>
        <source>Tree Pr&amp;operties</source>
        <translation>Pr&amp;opriedades da Árvore</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="921"/>
        <source>Ctrl+Shift+D</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="929"/>
        <source>Document &amp;Font</source>
        <translation>&amp;Fonte do Documento</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="943"/>
        <source>&amp;Wrap Lines</source>
        <translation>&amp;Linhas de Quebra Automática</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="946"/>
        <source>Ctrl+W</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="960"/>
        <source>&amp;Auto-Indentation</source>
        <translation>&amp;Indentação Automática</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="963"/>
        <source>Ctrl+Shift+I</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="968"/>
        <source>&amp;Preferences</source>
        <translation>&amp;Preferências</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="971"/>
        <source>Ctrl+Shift+P</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="979"/>
        <source>Find and &amp;Replace</source>
        <translation>Encontrar e &amp;Substituir</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="982"/>
        <source>Ctrl+R</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="990"/>
        <source>Ctrl+H</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="995"/>
        <source>&amp;About</source>
        <translation>&amp;Sobre</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1003"/>
        <source>Pr&amp;int All Nodes</source>
        <translation>Impr&amp;imir Todos Nós</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1014"/>
        <source>Superscrip&amp;t</source>
        <translation>Sobrescrit&amp;o</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1017"/>
        <source>Superscript</source>
        <translation>Sobrescrito</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1020"/>
        <source>Alt+Shift+U</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1031"/>
        <source>Subscri&amp;pt</source>
        <translation>Subscri&amp;to</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1034"/>
        <source>Subscript</source>
        <translation>Subscrito</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1037"/>
        <source>Alt+Shift+S</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1048"/>
        <source>C&amp;enter</source>
        <translation>C&amp;entralizado</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1051"/>
        <source>Align center</source>
        <translation>Alinhar no centro</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1054"/>
        <source>Alt+Shift+Down</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1065"/>
        <location filename="../../fn.cpp" line="2235"/>
        <source>&amp;Right</source>
        <translation>À &amp;Direita</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1068"/>
        <source>Align right</source>
        <translation>Alinhar na direita</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1071"/>
        <source>Alt+Shift+Right</source>
        <translation>Alt+Shift+Seta direita</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1082"/>
        <location filename="../../fn.cpp" line="2229"/>
        <source>&amp;Left</source>
        <translation>À &amp;Esquerda</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1085"/>
        <source>Align left</source>
        <translation>Alinhar na esquerda</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1088"/>
        <source>Alt+Shift+Left</source>
        <translation>Alt+Shift+Seta esquerda</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1099"/>
        <source>&amp;Justify</source>
        <translation>&amp;Justificado</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1102"/>
        <source>Justify</source>
        <translation>Justificado</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1105"/>
        <source>Alt+Shift+Up</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1113"/>
        <source>&amp;Prepend Sibling</source>
        <translation>&amp;Preferir Irmão</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1116"/>
        <source>Ctrl+M</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1124"/>
        <source>Move &amp;Left</source>
        <translation>Mover para &amp;Esquerda</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1127"/>
        <source>Alt+Left</source>
        <translation>Alt+Seta esquerda</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1135"/>
        <source>Move &amp;Right</source>
        <translation>Mover para &amp;Direita</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1138"/>
        <source>Alt+Right</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1146"/>
        <source>h&amp;2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1149"/>
        <source>Header 2</source>
        <translation>Cabeçalho 2</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1152"/>
        <source>Ctrl+2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1160"/>
        <source>h&amp;1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1163"/>
        <source>Header 1</source>
        <translation>Cabeçalho 1</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1166"/>
        <source>Ctrl+1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1174"/>
        <source>h&amp;3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1177"/>
        <source>Header 3</source>
        <translation>Cabeçalho 3</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1180"/>
        <source>Ctrl+3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1188"/>
        <source>&amp;Node Font</source>
        <translation>&amp;Fonte do Nó</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1191"/>
        <source>Node Font</source>
        <translation>Fonte do Nó</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1196"/>
        <source>Scale I&amp;mage(s)</source>
        <translation>Escala de I&amp;magem(ns)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1204"/>
        <source>Paste &amp;HTML</source>
        <translation>Colar &amp;HTML</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1207"/>
        <source>Ctrl+Shift+V</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1215"/>
        <source>&amp;Tags</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1218"/>
        <source>Ctrl+Shift+T</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1226"/>
        <source>Insert Lin&amp;k</source>
        <translation>Inserir Lin&amp;k</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1229"/>
        <source>Ctrl+L</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1234"/>
        <source>C&amp;opy Link</source>
        <translation>C&amp;opiar Link</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1242"/>
        <source>I&amp;nsert Table</source>
        <translation>I&amp;nserir Tabela</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1245"/>
        <source>Ctrl+Alt+Shift+T</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1250"/>
        <source>Append Row</source>
        <translation>Acrescentar Linha</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1255"/>
        <source>Delete Row</source>
        <translation>Excluir Linha</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1260"/>
        <source>Append Column</source>
        <translation>Acrescentar Coluna</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1265"/>
        <source>Delete Column</source>
        <translation>Excluir Coluna</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1270"/>
        <source>Merge Cells</source>
        <translation>Mesclar Células</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1275"/>
        <source>Prepend Row</source>
        <translation>Prefixar Linha</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1280"/>
        <source>Prepend Column</source>
        <translation>Prefixar Coluna</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1288"/>
        <source>Export &amp;HTML</source>
        <translation>Exportar &amp;HTML</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1293"/>
        <source>Save Ima&amp;ge(s)</source>
        <translation>Salvar Ima&amp;gem(ns)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1304"/>
        <source>RTL</source>
        <translation>Direita para Esquerda</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1307"/>
        <source>Ctrl+Alt+Shift+Left</source>
        <translation>Ctrl+Alt+Shift+Seta esquerda</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1318"/>
        <source>LTR</source>
        <translation>Esquerda para Direita</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1321"/>
        <source>Ctrl+Alt+Shift+Right</source>
        <translation>Ctrl+Alt+Shift+Seta direita</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1326"/>
        <location filename="../../fn.ui" line="1329"/>
        <source>Menu</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1337"/>
        <source>Node &amp;Icon</source>
        <translation>&amp;Ícone do Nó</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1340"/>
        <source>Ctrl+Shift+C</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1345"/>
        <location filename="../../fn.ui" line="1348"/>
        <source>Check Spelling</source>
        <translation>Verificar Ortografia</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1351"/>
        <source>F2</source>
        <translation>F2</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1356"/>
        <source>Document &amp;Colors</source>
        <translation>&amp;Cores do Documento</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1364"/>
        <location filename="../../fn.ui" line="1367"/>
        <source>Paste Date and Time</source>
        <translation>Colar Data e Hora</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1372"/>
        <source>&amp;Clear</source>
        <translation>&amp;Limpar</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3022"/>
        <source>Node Icon</source>
        <translation>Ícone do Nó</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="676"/>
        <source>&amp;Raise/Hide</source>
        <translation>&amp;Aumentar/ocultar</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="928"/>
        <source>&lt;center&gt;&lt;b&gt;&lt;big&gt;New note?&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;b&gt;&lt;big&gt;Nova nota?&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="929"/>
        <source>&lt;center&gt;&lt;i&gt;Do you really want to leave this document&lt;/i&gt;&lt;/center&gt;
&lt;center&gt;&lt;i&gt;and create an empty one?&lt;/i&gt;&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;i&gt;Você realmente quer deixar este documento&lt;/i&gt;&lt;/center&gt;
&lt;center&gt;&lt;i&gt;e criar um em branco?&lt;/i&gt;&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="932"/>
        <location filename="../../fn.cpp" line="2853"/>
        <location filename="../../fn.cpp" line="4812"/>
        <source>Yes</source>
        <translation>Sim</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="933"/>
        <location filename="../../fn.cpp" line="2854"/>
        <location filename="../../fn.cpp" line="4813"/>
        <source>No</source>
        <translation>Não</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1024"/>
        <source>&lt;center&gt;&lt;b&gt;&lt;big&gt;Save changes?&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;b&gt;&lt;big&gt;Salvar alterações?&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1026"/>
        <source>&lt;center&gt;&lt;i&gt;The document has been modified.&lt;/i&gt;&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;i&gt;O documento foi modificado.&lt;/i&gt;&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1028"/>
        <source>&lt;center&gt;&lt;i&gt;The document has been removed.&lt;/i&gt;&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;i&gt;O documento foi removido.&lt;/i&gt;&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1033"/>
        <source>Discard changes</source>
        <translation>Descartar alterações</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1034"/>
        <location filename="../../fn.cpp" line="2971"/>
        <location filename="../../fn.cpp" line="3065"/>
        <location filename="../../fn.cpp" line="3346"/>
        <location filename="../../fn.cpp" line="4388"/>
        <location filename="../../fn.cpp" line="4473"/>
        <location filename="../../fn.cpp" line="4651"/>
        <location filename="../../fn.cpp" line="4914"/>
        <location filename="../../fn.cpp" line="5867"/>
        <location filename="../../fn.cpp" line="6146"/>
        <location filename="../../fn.cpp" line="6244"/>
        <location filename="../../fn.cpp" line="6344"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1497"/>
        <source>Open file...</source>
        <translation>Abrir arquivo...</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1674"/>
        <location filename="../../fn.cpp" line="5993"/>
        <source>&lt;center&gt;&lt;b&gt;&lt;big&gt;Cannot be saved!&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;b&gt;&lt;big&gt;Não pode ser salvo!&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3642"/>
        <source>Close</source>
        <translation>Fechar</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1774"/>
        <location filename="../../fn.cpp" line="1797"/>
        <source>Save As...</source>
        <translation>Salvar Como...</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1499"/>
        <location filename="../../fn.cpp" line="1776"/>
        <location filename="../../fn.cpp" line="1799"/>
        <source>FeatherNotes documents</source>
        <translation>Documentos do FeatherNotes</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1499"/>
        <location filename="../../fn.cpp" line="1776"/>
        <location filename="../../fn.cpp" line="1799"/>
        <location filename="../../fn.cpp" line="3054"/>
        <location filename="../../fn.cpp" line="4572"/>
        <location filename="../../fn.cpp" line="4843"/>
        <source>All Files</source>
        <translation>Todos os Arquivos</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2850"/>
        <source>&lt;center&gt;&lt;b&gt;&lt;big&gt;Delete this node?&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;b&gt;&lt;big&gt;Excluir este nó?&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2851"/>
        <source>&lt;center&gt;&lt;b&gt;&lt;i&gt;Warning!&lt;/i&gt;&lt;/b&gt;&lt;/center&gt;
&lt;center&gt;This action cannot be undone.&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;b&gt;&lt;i&gt;Atenção!&lt;/i&gt;&lt;/b&gt;&lt;/center&gt;
&lt;center&gt;Essa ação não pode ser desfeita.&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2957"/>
        <source>Tags</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2972"/>
        <location filename="../../fn.cpp" line="3066"/>
        <location filename="../../fn.cpp" line="3347"/>
        <location filename="../../fn.cpp" line="4390"/>
        <location filename="../../fn.cpp" line="4474"/>
        <location filename="../../fn.cpp" line="4652"/>
        <location filename="../../fn.cpp" line="4915"/>
        <location filename="../../fn.cpp" line="5869"/>
        <location filename="../../fn.cpp" line="6147"/>
        <location filename="../../fn.cpp" line="6245"/>
        <location filename="../../fn.cpp" line="6345"/>
        <source>OK</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3054"/>
        <location filename="../../fn.cpp" line="4572"/>
        <location filename="../../fn.cpp" line="4843"/>
        <source>Image Files</source>
        <translation>Arquivos de imagem</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3154"/>
        <location filename="../../fn.cpp" line="3187"/>
        <source>&lt;b&gt;Main nodes:&lt;/b&gt; &lt;i&gt;%1&lt;/i&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&lt;b&gt;All nodes:&lt;/b&gt; &lt;i&gt;%2&lt;/i&gt;</source>
        <translation>&lt;b&gt;Principais nós:&lt;/b&gt; &lt;i&gt;%1&lt;/i&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&lt;b&gt;Todos os nós:&lt;/b&gt; &lt;i&gt;%2&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3160"/>
        <location filename="../../fn.cpp" line="3193"/>
        <source>&lt;b&gt;Note:&lt;/b&gt; &lt;i&gt;%1&lt;/i&gt;&lt;br&gt;&lt;b&gt;Main nodes:&lt;/b&gt; &lt;i&gt;%2&lt;/i&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&lt;b&gt;All nodes:&lt;/b&gt; &lt;i&gt;%3&lt;/i&gt;</source>
        <translation>&lt;b&gt;Nota:&lt;/b&gt; &lt;i&gt;%1&lt;/i&gt;&lt;br&gt;&lt;b&gt;Principais nós:&lt;/b&gt; &lt;i&gt;%2&lt;/i&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&lt;b&gt;Todos os nós:&lt;/b&gt; &lt;i&gt;%3&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3629"/>
        <source>%1 Matches</source>
        <translation>%1 Correspondências</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3631"/>
        <source>One Match</source>
        <translation>Uma correspondência</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3633"/>
        <location filename="../../fn.cpp" line="4004"/>
        <source>No Match</source>
        <translation>Sem correspondência</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3799"/>
        <location filename="../../fn.cpp" line="3852"/>
        <source>Replacement</source>
        <translation>Substituição</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4111"/>
        <source>No Replacement</source>
        <translation>Nenhuma substituição</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4113"/>
        <source>One Replacement</source>
        <translation>Uma substituição</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4116"/>
        <source>%1 Replacements</source>
        <translation>%1 Substituições</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4376"/>
        <source>Insert Link</source>
        <translation>Inserir link</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6090"/>
        <source>HTML Files</source>
        <translation>Arquivos HTML</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3030"/>
        <location filename="../../fn.cpp" line="4458"/>
        <source>Image path</source>
        <translation>Caminho da imagem</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3034"/>
        <location filename="../../fn.cpp" line="4462"/>
        <source>Open image</source>
        <translation>Abrir imagem</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4470"/>
        <location filename="../../fn.cpp" line="4648"/>
        <source>Scaling percentage</source>
        <translation>Escala de porcentagem</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3052"/>
        <location filename="../../fn.cpp" line="4570"/>
        <source>Open Image...</source>
        <translation>Abrir imagem...</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="653"/>
        <source>System tray is not available.
Please disable tray in Preferences.</source>
        <translation>A bandeja do sistema não está disponível.
Por favor, desative a bandeja em Preferências.</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="979"/>
        <source>New Node</source>
        <translation>Novo Nó</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1675"/>
        <source>&lt;center&gt;&lt;b&gt;&lt;big&gt;Cannot be opened!&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;b&gt;&lt;big&gt;Não pode ser aberto!&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1756"/>
        <location filename="../../fn.cpp" line="5708"/>
        <location filename="../../fn.cpp" line="5717"/>
        <location filename="../../fn.cpp" line="5856"/>
        <location filename="../../fn.cpp" line="6047"/>
        <location filename="../../fn.cpp" line="6056"/>
        <location filename="../../fn.cpp" line="6083"/>
        <source>Untitled</source>
        <translation>Sem título</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2228"/>
        <source>Align Table</source>
        <translation>Alinhar Tabela</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2241"/>
        <source>&amp;Center</source>
        <translation>&amp;Centro</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2680"/>
        <source>Select Text Color</source>
        <translation>Selecionar Cor do Texto</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2712"/>
        <source>Select Background Color</source>
        <translation>Selecionar Cor de Fundo</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2849"/>
        <source>Deletion</source>
        <translation>Exclusão</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2967"/>
        <source>Tag(s) for this node</source>
        <translation>Tag(s) para este nó</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3231"/>
        <source>Select Document Font</source>
        <translation>Selecionar Fonte do Documento</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3293"/>
        <source>Select Node Font</source>
        <translation>Selecionar Fonte do Nó</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3318"/>
        <source>Set Document Colors</source>
        <translation>Definir Cores do Documento</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3328"/>
        <source>These colors will be applied to new nodes.&lt;br&gt;They may or may not affect existing nodes&lt;br&gt;but document reopening is recommended.</source>
        <translation>Essas cores serão aplicadas a novos nós.&lt;br&gt;Eles podem ou não afetar os nós existentes,&lt;br&gt;mas a reabertura do documento é recomendada.</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3331"/>
        <source>Background color:</source>
        <translation>Cor de fundo:</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3337"/>
        <source>Text color:</source>
        <translation>Cor do texto:</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4121"/>
        <source>The first 1000 replacements are highlighted.</source>
        <translation>As primeiras 1000 substituições são destacadas.</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4465"/>
        <location filename="../../fn.cpp" line="4644"/>
        <source>Scale to</source>
        <translation>Escala para</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4469"/>
        <location filename="../../fn.cpp" line="4647"/>
        <source>%</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4638"/>
        <source>Scale Image(s)</source>
        <translation>Escala da Imagem(ns)</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4775"/>
        <source>untitled</source>
        <translation>sem título</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4807"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4808"/>
        <source>&lt;center&gt;&lt;b&gt;&lt;big&gt;Image cannot be saved! Retry?&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;b&gt;&lt;big&gt;Imagem não pode ser salva! Tentar novamente?&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4809"/>
        <source>&lt;center&gt;Maybe you did not choose a proper extension&lt;/center&gt;
&lt;center&gt;or do not have write permission.&lt;/center&gt;&lt;p&gt;&lt;/p&gt;</source>
        <translation>&lt;center&gt;Talvez você não tenha escolhido uma extensão adequada&lt;/center&gt;
&lt;center&gt;ou não tem permissão de gravação.&lt;/center&gt;&lt;p&gt;&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4841"/>
        <source>Save Image As...</source>
        <translation>Salvar Imagem Como...</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4896"/>
        <source>Insert Table</source>
        <translation>Inserir Tabela</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4902"/>
        <source>Rows:</source>
        <translation>Linhas:</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4908"/>
        <source>Columns:</source>
        <translation>Colunas:</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5797"/>
        <source>Print Document</source>
        <translation>Imprimir Documento</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5803"/>
        <source>Printing completed.</source>
        <translation>Impressão concluída.</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5805"/>
        <source>Printing in progress...</source>
        <translation>Impressão em andamento...</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5824"/>
        <source>Export HTML</source>
        <translation>Exportar HTML</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5829"/>
        <source>Export:</source>
        <translation>Exportar:</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5830"/>
        <source>&amp;Current node</source>
        <translation>&amp;Nó atual</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5832"/>
        <source>With all &amp;sub-nodes</source>
        <translation>Com todos os &amp;sub-nós</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5833"/>
        <source>&amp;All nodes</source>
        <translation>&amp;Todos os nós</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5845"/>
        <source>Output file:</source>
        <translation>Arquivo de saída:</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5864"/>
        <source>Select path</source>
        <translation>Selecionar caminho</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5905"/>
        <source>Question</source>
        <translation>Questão</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5906"/>
        <source>The file already exists.
Do you want to replace it?
</source>
        <translation>O arquivo já existe.
Você deseja substituir?
</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6088"/>
        <source>Save HTML As...</source>
        <translation>Salvar HTML Como...</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6114"/>
        <source>Set Password</source>
        <translation>Definir Senha</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6123"/>
        <source>Type password</source>
        <translation>Digite a senha</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6135"/>
        <source>Retype password</source>
        <translation>Redigite a senha</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6207"/>
        <source>&lt;center&gt;Passwords were different. Retry!&lt;/center&gt;</source>
        <translation>&lt;center&gt;As senhas não conferem. Tente novamente!&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6227"/>
        <location filename="../../fn.cpp" line="6235"/>
        <location filename="../../fn.cpp" line="6327"/>
        <location filename="../../fn.cpp" line="6335"/>
        <source>Enter Password</source>
        <translation>Digite a senha</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6307"/>
        <location filename="../../fn.cpp" line="6341"/>
        <source>&lt;center&gt;Wrong password. Retry!&lt;/center&gt;</source>
        <translation>&lt;center&gt;Senha incorreta. Tente novamente!&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6408"/>
        <source>A lightweight notes manager</source>
        <translation>Um gerenciador de notas leve</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6409"/>
        <source>based on Qt</source>
        <translation>baseado no Qt</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6410"/>
        <source>Author</source>
        <translation>Autor</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6412"/>
        <location filename="../../fn.cpp" line="6413"/>
        <source>About FeatherNotes</source>
        <translation>Sobre FeatherNotes</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6412"/>
        <source>Translators</source>
        <translation>Tradutores</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6596"/>
        <source>See Preferences → Text → Spell Checking!</source>
        <translation>Veja em Preferências → Texto → Verificação Ortográfica!</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6612"/>
        <source>You need to add a Hunspell dictionary.</source>
        <translation>Você precisa adicionar um dicionário Hunspell.</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6617"/>
        <source>The Hunspell dictionary does not exist.</source>
        <translation>O dicionário Hunspell não existe.</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6625"/>
        <source>The Hunspell dictionary is not accompanied by an affix file.</source>
        <translation>O dicionário Hunspell não é acompanhado por um arquivo afixo.</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6643"/>
        <location filename="../../fn.cpp" line="6658"/>
        <location filename="../../fn.cpp" line="6670"/>
        <source>No misspelling from text cursor.</source>
        <translation>Sem erros ortográficos do cursor de texto.</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6682"/>
        <source>Spell Checking</source>
        <translation>Verificando Ortografia</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6411"/>
        <source>aka.</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>FeatherNotes::LineEdit</name>
    <message>
        <location filename="../../lineedit.cpp" line="35"/>
        <source>Clear text (Ctrl+K)</source>
        <translation>Limpar texto (Ctrl+K)</translation>
    </message>
    <message>
        <location filename="../../lineedit.cpp" line="81"/>
        <source>Ctrl+K</source>
        <comment>Clear text</comment>
        <translation></translation>
    </message>
</context>
<context>
    <name>FeatherNotes::PrefDialog</name>
    <message>
        <location filename="../../prefDialog.ui" line="14"/>
        <source>Preferences</source>
        <translation>Preferências</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="27"/>
        <source>Window</source>
        <translation>Janela</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="36"/>
        <source>Saves window size after closing
this dialog and also on exit.

Uncheck to set a fixed size!</source>
        <translation>Salva o tamanho da janela após fechar
este diálogo e também ao sair.

Desmarque para definir um tamanho fixo!</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="42"/>
        <source>Remember window &amp;size</source>
        <translation>Memorizar &amp;tamanho da janela</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="51"/>
        <source>Start with this size: </source>
        <translation>Iniciar com esse tamanho: </translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="58"/>
        <location filename="../../prefDialog.ui" line="72"/>
        <source> px</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="97"/>
        <source>Saves tree width after closing
this dialog and also on exit.

Uncheck for a width ratio of 170/530.</source>
        <translation>Salva a largura da árvore após fechar
este diálogo e também ao sair.

Desmarque para uma taxa de largura de 170/530.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="103"/>
        <source>Remember &amp;tree width</source>
        <translation>Memorizar largura da Ár&amp;vore</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="110"/>
        <source>Saves position after closing
this dialog and also on exit.

This may not work correctly
with some window managers.</source>
        <translation>Salva a posição após fechar
esta janela e também ao sair.

Isto pode não funcionar corretamente
com alguns gerenciadores de janelas.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="117"/>
        <source>Save &amp;position</source>
        <translation>Salvar &amp;posição</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="124"/>
        <source>Decides whether a systray icon should be used.
If checked, the titlebar close button iconifies
the window to the systray instead of quitting.

Needs restarting of FeatherNotes to take effect.</source>
        <translation>Decide se um ícone da bandeja do sistema deve ser usado.
Se marcado, o botão de fechar da barra de título iconifica
a janela para a bandeja do sistema em vez de sair.

Necessário reiniciar o FeatherNotes para entrar em vigor.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="131"/>
        <source>Add to s&amp;ystray</source>
        <translation>Adicionar à área de no&amp;tificação</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="156"/>
        <source>The command line option --tray
can be used instead of this.</source>
        <translation>A opção de linha de comando --tray
pode ser usado em vez disso.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="160"/>
        <source>Start i&amp;conified to tray</source>
        <translation>Iniciar mi&amp;nimizado para bandeja</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="169"/>
        <source>Merge the tree view with its surroundings?</source>
        <translation>Mesclar a visualização da árvore com o seu arredor?</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="172"/>
        <source>Transparent t&amp;ree view</source>
        <translation>Visualização de á&amp;rvore transparente</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="179"/>
        <source>By default, the active widget style determines
the size of toolbar icons.</source>
        <translation>Por padrão, o estilo de widget ativo determina o
tamanho dos ícones da barra de ferramentas.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="183"/>
        <source>Small toolbar icons</source>
        <translation>Ícones pequenos na barra de ferramenta</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="190"/>
        <source>Do not show t&amp;oolbar</source>
        <translation>Não exibir barra de f&amp;erramenta</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="197"/>
        <source>If the menubar is hidden,
a menu button appears on the toolbar.</source>
        <translation>Se a barra de menu estiver oculta,
um botão de menu aparecerá na barra de ferramentas.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="201"/>
        <source>Do not show &amp;menubar</source>
        <translation>Não exibir barra de &amp;menu</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="228"/>
        <source>Text</source>
        <translation>Texto</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="237"/>
        <source>&amp;Wrap lines by default</source>
        <translation>&amp;Quebra de linhas por padrão</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="244"/>
        <source>Auto-&amp;indent by default</source>
        <translation>&amp;Indentação automática por padrão</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="251"/>
        <source>This covers parentheses, braces, brackets and quotes.

Needs restarting of FeatherNotes to take effect.</source>
        <translation>Isso abrange parênteses, chaves, colchetes e citações.

Necessário reiniciar o FeatherNotes para entrar em vigor.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="256"/>
        <source>Auto-&amp;bracket</source>
        <translation>&amp;Colchete automático</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="263"/>
        <source>A triple period is replaced with an ellipsis,
a double hyphen with a long dash, etc. while
the user is typing and under proper circumstances.</source>
        <translation>Um período triplo é substituído por uma elipse,
um hífen duplo com um traço longo, etc. Enquanto
o usuário está digitando e em circunstâncias adequadas.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="268"/>
        <source>&amp;Replace some characters while typing</source>
        <translation>&amp;Substitua alguns caracteres enquanto digita</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="277"/>
        <location filename="../../prefDialog.ui" line="290"/>
        <source>Used for pasting the date and time.
Leave empty for the system default.

Takes effect after closing this dialog.</source>
        <translation>Usado para colar a data e a hora.
Deixe em branco para o padrão do sistema.

Entra em vigor após fechar esta caixa de diálogo.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="283"/>
        <source>Date and time format:</source>
        <translation>Formato de data e hora:</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="307"/>
        <source>&amp;Auto-save every</source>
        <translation>Salvar tudo &amp;automaticamente</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="314"/>
        <source> minute(s)</source>
        <translation> minuto(s)</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="348"/>
        <source>If this option is checked, the opened document will
be saved on exiting without prompt and without
showing a warning if saving is not possible.</source>
        <translation>Se esta opção for marcada, o documento aberto
será salvo ao sair sem perguntar e não mostrará
um aviso se não for possível salvar.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="353"/>
        <source>Save opened document on exiting</source>
        <translation>Salvar documento aberto a sair</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="376"/>
        <source>Spell Checking</source>
        <translation>Verificação Ortográfica</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="384"/>
        <location filename="../../prefDialog.ui" line="396"/>
        <source>A Hunspell dictionary has a name that ends with &quot;.dic&quot;
and should be alongside an affix file with the same
name but ending with &quot;.aff&quot;.</source>
        <translation>Um dicionário Hunspell tem um nome que termina com &quot;.dic&quot;
e deve estar ao lado de um arquivo afixo com o mesmo
nome, mas terminando com &quot;.aff&quot;.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="389"/>
        <source>Hunspell dictionary path:</source>
        <translation>Endereço do dicionário Hunspell:</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="408"/>
        <location filename="../../pref.cpp" line="653"/>
        <source>Add dictionary...</source>
        <translation>Adicionar dicionário...</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="443"/>
        <source>Files</source>
        <translation>Arquivos</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="452"/>
        <source>Start with the last opened file</source>
        <translation>Iniciar com o último arquivo aberto</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="464"/>
        <source>Number of recent files:</source>
        <translation>Número de arquivos recentes:</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="496"/>
        <source>Open recent files separately</source>
        <translation>Abra os arquivos recentes separadamente</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="503"/>
        <source>By default, all nodes are expanded on opening a document.</source>
        <translation>Por padrão, todos os nós são expandidos ao abrir um documento.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="506"/>
        <source>Remember expanded states of nodes</source>
        <translation>Lembrar estados de expansão dos nós</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="530"/>
        <source>Shortcuts</source>
        <translation>Atalhos</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="549"/>
        <source>Action</source>
        <translation>Ação</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="554"/>
        <source>Shortcut</source>
        <translation>Atalho</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="562"/>
        <source>Default</source>
        <translation>Padrão</translation>
    </message>
    <message>
        <location filename="../../pref.cpp" line="346"/>
        <location filename="../../pref.cpp" line="526"/>
        <source>Warning: Ambiguous shortcut detected!</source>
        <translation>Atenção: Atalho ambíguo detectado!</translation>
    </message>
    <message>
        <location filename="../../pref.cpp" line="509"/>
        <source>The typed shortcut was reserved.</source>
        <translation>O atalho digitado foi reservado.</translation>
    </message>
    <message>
        <location filename="../../pref.cpp" line="624"/>
        <source>Application restart is needed for changes to take effect.</source>
        <translation>A reinicialização do aplicativo é necessária para que as alterações entrem em vigor.</translation>
    </message>
    <message>
        <location filename="../../pref.cpp" line="655"/>
        <source>Hunspell Dictionary Files</source>
        <translation>Arquivos de Dicionário Hunspell</translation>
    </message>
</context>
<context>
    <name>FeatherNotes::SpellDialog</name>
    <message>
        <location filename="../../spellDialog.ui" line="25"/>
        <source>Unknown word:</source>
        <translation>Palavra desconhecida:</translation>
    </message>
    <message>
        <location filename="../../spellDialog.ui" line="51"/>
        <source>Add To Dictionary</source>
        <translation>Adicionar ao Dicionário</translation>
    </message>
    <message>
        <location filename="../../spellDialog.ui" line="62"/>
        <source>Replace with:</source>
        <translation>Substituir com:</translation>
    </message>
    <message>
        <location filename="../../spellDialog.ui" line="87"/>
        <source>Ignore Once</source>
        <translation>Ignorar Uma Vez</translation>
    </message>
    <message>
        <location filename="../../spellDialog.ui" line="100"/>
        <source>Ignore All</source>
        <translation>Ignorar Tudo</translation>
    </message>
    <message>
        <location filename="../../spellDialog.ui" line="129"/>
        <source>Correct Once</source>
        <translation>Corrigir Uma Vez</translation>
    </message>
    <message>
        <location filename="../../spellDialog.ui" line="142"/>
        <source>Correct All</source>
        <translation>Corrigir Tudo</translation>
    </message>
</context>
<context>
    <name>FeatherNotes::helpDialog</name>
    <message>
        <location filename="../../helpDialog.ui" line="14"/>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../domitem.cpp" line="101"/>
        <location filename="../../domitem.cpp" line="103"/>
        <location filename="../../domitem.cpp" line="142"/>
        <location filename="../../domitem.cpp" line="144"/>
        <source>New Node</source>
        <translation>Novo Nó</translation>
    </message>
</context>
</TS>
